@@ -16,12 +16,15 @@ from .parser import Parser
 from .writer import Writer
 from .validate import validate
 from .exceptions import TabulatorException
-from .exceptions import IOError
-from .exceptions import HTTPError
 from .exceptions import SourceError
+from .exceptions import SchemeError
 from .exceptions import FormatError
 from .exceptions import EncodingError
+from .exceptions import CompressionError
 
 # Deprecated
 
 from . import exceptions
+from .exceptions import IOError
+from .exceptions import LoadingError
+from .exceptions import HTTPError
