@@ -8,20 +8,23 @@ import pytest
 from tabulator import Stream, exceptions
 
 
-# Stream
+# Read
 
+@pytest.mark.remote
 def test_stream_gsheet():
     source = 'https://docs.google.com/spreadsheets/d/1mHIWnDvW9cALRMq9OdNfRwjAthCUFUOACPp0Lkyl7b4/edit?usp=sharing'
     with Stream(source) as stream:
         assert stream.read() == [['id', 'name'], ['1', 'english'], ['2', '中国人']]
 
 
+@pytest.mark.remote
 def test_stream_gsheet_with_gid():
     source = 'https://docs.google.com/spreadsheets/d/1mHIWnDvW9cALRMq9OdNfRwjAthCUFUOACPp0Lkyl7b4/edit#gid=960698813'
     with Stream(source) as stream:
         assert stream.read() == [['id', 'name'], ['2', '中国人'], ['3', 'german']]
 
 
+@pytest.mark.remote
 def test_stream_gsheet_bad_url():
     stream = Stream('https://docs.google.com/spreadsheets/d/bad')
     with pytest.raises(exceptions.HTTPError) as excinfo:
