@@ -14,7 +14,7 @@ from tabulator.parsers.xls import XLSParser
 BASE_URL = 'https://raw.githubusercontent.com/okfn/tabulator-py/master/%s'
 
 
-# Stream
+# Read
 
 def test_stream_local_xls():
     with Stream('data/table.xls') as stream:
@@ -22,6 +22,7 @@ def test_stream_local_xls():
         assert stream.read() == [['id', 'name'], [1, 'english'], [2, '中国人']]
 
 
+@pytest.mark.remote
 def test_stream_remote_xls():
     with Stream(BASE_URL % 'data/table.xls') as stream:
         assert stream.headers is None
@@ -94,12 +95,13 @@ def test_stream_xls_with_ints_floats_dates():
                                  [1997, 5.6, datetime(2009, 9, 20)],
                                  [1969, 11.7, datetime(2012, 8, 23)]]
 
+@pytest.mark.remote
 def test_fix_for_2007_xls():
     source = 'https://ams3.digitaloceanspaces.com/budgetkey-files/spending-reports/2018-3-משרד התרבות והספורט-לשכת הפרסום הממשלתית-2018-10-22-c457.xls'
     with Stream(source) as stream:
         assert len(stream.read()) > 10
 
-# Parser
+# Internal
 
 def test_parser_xls():
 
